@@ -54,6 +54,41 @@ class TestTree(unittest.TestCase):
     def test_appending(self):
         tree = easytree.new()
         tree.append({"make":"Saab","color":"blue"})
+        tree.append(make="Toyota", color="red")
 
         self.assertIsInstance(easytree.serialize(tree), list)
-        self.assertIsInstance(tree[0], easytree.Tree)
\ No newline at end of file
+        self.assertIsInstance(tree[0], easytree.Tree)
+        self.assertIsInstance(tree[1], easytree.Tree)
+
+    def test_indexing(self):
+        tree = easytree.new()
+
+        with self.assertRaises(IndexError):
+            tree[0] = "test"
+
+        tree = easytree.new()
+        tree.append("test") #convert to list-node
+        self.assertEqual(easytree.serialize(tree)[0], "test")
+
+        tree = easytree.new({0:"test"}) #convert to dict-node
+        self.assertEqual(easytree.serialize(tree)[0], "test")
+
+    def test_length(self):
+        tree = easytree.new([1,2,3])
+        self.assertEqual(len(tree), 3)
+
+        tree = easytree.new({"name":"David","age":29})
+        self.assertEqual(len(tree), 2)
+
+        with self.assertRaises(TypeError):
+            len(easytree.new(1))
+
+    def test_iteration(self):
+        tree = easytree.new([1,2,3])
+        for child in tree: 
+            self.assertIsInstance(child, easytree.Tree)
+
+        tree = easytree.new({"name":"David","age":29})
+        for child in tree: 
+            self.assertIsInstance(child, str)
+
